==> icinga2_2.8.1.orig.tar.gz: icinga2-2.8.1/lib/cli/apisetuputility.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef APISETUPUTILITY_H
#define APISETUPUTILITY_H

#include "base/i2-base.hpp"
#include "cli/i2-cli.hpp"
#include "base/dictionary.hpp"
#include "base/array.hpp"
#include "base/value.hpp"
#include "base/string.hpp"
#include <vector>

namespace icinga
{

/**
 * @ingroup cli
 */
class I2_CLI_API ApiSetupUtility
{
public:
	static bool SetupMaster(const String& cn, bool prompt_restart = false);

	static bool SetupMasterCertificates(const String& cn);
	static bool SetupMasterApiUser(void);
	static bool SetupMasterEnableApi(void);

	static String GetConfdPath(void);

private:
	ApiSetupUtility(void);
};

}

#endif /* APISETUPUTILITY_H */

==> icinga2_2.9.0.orig.tar.gz: icinga2-2.9.0/lib/cli/apisetuputility.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef APISETUPUTILITY_H
#define APISETUPUTILITY_H

#include "base/i2-base.hpp"
#include "cli/i2-cli.hpp"
#include "base/dictionary.hpp"
#include "base/array.hpp"
#include "base/value.hpp"
#include "base/string.hpp"
#include <vector>

namespace icinga
{

/**
 * @ingroup cli
 */
class ApiSetupUtility
{
public:
	static bool SetupMaster(const String& cn, bool prompt_restart = false);

	static bool SetupMasterCertificates(const String& cn);
	static bool SetupMasterApiUser();
	static bool SetupMasterEnableApi();
	static bool SetupMasterUpdateConstants(const String& cn);

	static String GetConfdPath();
	static String GetApiUsersConfPath();

private:
	ApiSetupUtility();
};

}

#endif /* APISETUPUTILITY_H */
